# Change log for jsun

## 1.0a1 - 2021-11-03

This is the initial standalone version of this package. It was spun out
of the [https://github.com/wylee/django-local-settings](django-local-settings)
package.
